# Generated by roxygen2: do not edit by hand

S3method(plot,twoCoprimary)
S3method(print,twoCoprimary)
S3method(print,twoCoprimary_table)
export(corrbound2Binary)
export(corrbound2MixedCountContinuous)
export(dbibinom)
export(design_table)
export(power2BinaryApprox)
export(power2BinaryExact)
export(power2Continuous)
export(power2MixedContinuousBinary)
export(power2MixedCountContinuous)
export(rr1Binary)
export(ss1BinaryApprox)
export(ss1Continuous)
export(ss1Count)
export(ss2BinaryApprox)
export(ss2BinaryExact)
export(ss2Continuous)
export(ss2MixedContinuousBinary)
export(ss2MixedCountContinuous)
export(twoCoprimary2BinaryApprox)
export(twoCoprimary2BinaryExact)
export(twoCoprimary2Continuous)
export(twoCoprimary2MixedContinuousBinary)
export(twoCoprimary2MixedCountContinuous)
import(fpCompare)
importFrom(graphics,abline)
importFrom(graphics,contour)
importFrom(graphics,grid)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(mvtnorm,rmvnorm)
importFrom(pbivnorm,pbivnorm)
importFrom(stats,dbinom)
importFrom(stats,dhyper)
importFrom(stats,dnorm)
importFrom(stats,integrate)
importFrom(stats,pbinom)
importFrom(stats,phyper)
importFrom(stats,pnbinom)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qnbinom)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,rWishart)
